@@ -50,6 +50,15 @@ void RarTime::GetLocal(RarLocalTime *lt)
   SystemTimeToTzSpecificLocalTime(NULL,&st1,&st2);
   SystemTimeToFileTime(&st2,&lft);
 
+  // Correct precision loss (low 4 decimal digits) in FileTimeToSystemTime.
+  FILETIME rft;
+  SystemTimeToFileTime(&st1,&rft);
+  int64 Corrected=INT32TO64(ft.dwHighDateTime,ft.dwLowDateTime)-
+                  INT32TO64(rft.dwHighDateTime,rft.dwLowDateTime)+
+                  INT32TO64(lft.dwHighDateTime,lft.dwLowDateTime);
+  lft.dwLowDateTime=(DWORD)Corrected;
+  lft.dwHighDateTime=(DWORD)(Corrected>>32);
+
   SYSTEMTIME st;
   FileTimeToSystemTime(&lft,&st);
   lt->Year=st.wYear;
@@ -119,6 +128,15 @@ void RarTime::SetLocal(RarLocalTime *lt)
     FILETIME ft;
     SystemTimeToFileTime(&st1,&ft);
 
+    // Correct precision loss (low 4 decimal digits) in FileTimeToSystemTime.
+    FILETIME rft;
+    SystemTimeToFileTime(&st2,&rft);
+    int64 Corrected=INT32TO64(lft.dwHighDateTime,lft.dwLowDateTime)-
+                    INT32TO64(rft.dwHighDateTime,rft.dwLowDateTime)+
+                    INT32TO64(ft.dwHighDateTime,ft.dwLowDateTime);
+    ft.dwLowDateTime=(DWORD)Corrected;
+    ft.dwHighDateTime=(DWORD)(Corrected>>32);
+
     *this=ft;
   }
   else
@@ -260,7 +278,6 @@ void RarTime::SetAgeText(const wchar *TimeText)
     }
   }
   SetCurrentTime();
-  int64 RawTime=GetRaw();
   SetRaw(itime-uint64(Seconds)*10000000);
 }
 #endif
