@@ -55,8 +55,10 @@ bool ExtractUnixLink50(const wchar *Name,FileHeader *hd)
   if (hd->RedirType==FSREDIR_WINSYMLINK || hd->RedirType==FSREDIR_JUNCTION)
   {
     // Cannot create Windows absolute path symlinks in Unix. Only relative path
-    // Windows symlinks can be created here.
-    if (strncmp(Target,"\\??\\",4)==0)
+    // Windows symlinks can be created here. RAR 5.0 used \??\ prefix
+    // for Windows absolute symlinks, since RAR 5.1 /??/ is used.
+    // We escape ? as \? to avoid "trigraph" warning
+    if (strncmp(Target,"\\??\\",4)==0 || strncmp(Target,"/\?\?/",4)==0)
       return false;
     DosSlashToUnix(Target,Target,ASIZE(Target));
   }
